summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/clipboard/umlclipboard.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:09 -0600
commit3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b (patch)
tree4405f233f4b0eee7f4ad3d265a5584c9ce681011 /umbrello/umbrello/clipboard/umlclipboard.cpp
parentd6331f1b56eb6dca7a1950658b2932f208015da0 (diff)
downloadtdesdk-3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b.tar.gz
tdesdk-3b34e5cf56262c9f54a3bcf02ee5ad93ca0fb05b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit d6331f1b56eb6dca7a1950658b2932f208015da0.
Diffstat (limited to 'umbrello/umbrello/clipboard/umlclipboard.cpp')
-rw-r--r--umbrello/umbrello/clipboard/umlclipboard.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/clipboard/umlclipboard.cpp b/umbrello/umbrello/clipboard/umlclipboard.cpp
index 069ba84b..d654e083 100644
--- a/umbrello/umbrello/clipboard/umlclipboard.cpp
+++ b/umbrello/umbrello/clipboard/umlclipboard.cpp
@@ -267,7 +267,7 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* Item, bool & WithDiagra
}
}
/** Adds the children of a UMLListViewItem to m_ItemList */
bool UMLClipboard::insertItemChildren(UMLListViewItem * Item, UMLListViewItemList& SelectedItems) {
if(Item->childCount()) {
UMLListViewItem * child = (UMLListViewItem*)Item->firstChild();
@@ -347,7 +347,7 @@ bool UMLClipboard::pasteClip1(TQMimeSource* data) {
return true;
lv->setStartedCopy(false);
/* If we get here we are pasting after a Copy and need to
// paste possible children.
UMLListViewItem* itemdata = 0;
UMLListViewItemListIt it(itemdatalist);
while ( (itemdata=it.current()) != 0 ) {
@@ -630,7 +630,7 @@ bool UMLClipboard::pasteClip5(TQMimeSource* data) {
break;
}
default :
- kWarning() << "pasting unknown children type in clip type 5" << endl;
+ kWarning() << "pasting unknown tqchildren type in clip type 5" << endl;
return false;
}
}
@@ -267,7 +267,7 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* Item, bool & WithDiagra
}
}
-/** Adds the children of a UMLListViewItem to m_ItemList */
+/** Adds the tqchildren of a UMLListViewItem to m_ItemList */
bool UMLClipboard::insertItemChildren(UMLListViewItem * Item, UMLListViewItemList& SelectedItems) {
if(Item->childCount()) {
@@ -347,7 +347,7 @@ bool UMLClipboard::pasteClip1(TQMimeSource* data) {
lv->setStartedCopy(false);
/* If we get here we are pasting after a Copy and need to
- // paste possible children.
+ // paste possible tqchildren.
UMLListViewItem* itemdata = 0;
UMLListViewItemListIt it(itemdatalist);